@@ -14,7 +14,7 @@ makeSplot <- function(Splot,
                       header="v3",
                       window.size = "800x1100", # in px
                       returnObj = TRUE
-
+                     
                       ){
 
   # set up file names
@@ -24,7 +24,7 @@ makeSplot <- function(Splot,
   fname.tiff=paste(dir,fname.root,".tif",sep="")
   fname.html=paste(dir,fname.root,".html",sep="")
   fname.pdf=paste(dir,fname.root,".pdf",sep="")
-
+  
   #
   # create static image
   #
@@ -40,7 +40,7 @@ makeSplot <- function(Splot,
     }
     if(!is.na(overwriteSourcePlot) & ((overwriteSourcePlot != "png") & (overwriteSourcePlot != "jpeg"))){
       overwriteSourcePlot = c("png", overwriteSourcePlot)
-    }
+    }                                     
     if(is.na(overwriteSourcePlot[1]))  overwriteSourcePlot = Splot$source.plot
 
     pngF = length(which(overwriteSourcePlot == "png")) > 0
@@ -48,54 +48,54 @@ makeSplot <- function(Splot,
     tiffF = length(which(overwriteSourcePlot == "tiff")) > 0
     jpegF = length(which(overwriteSourcePlot == "jpeg")) > 0
     pdfF = length(which(overwriteSourcePlot == "pdf")) > 0
-
-
+       
+ 
   }else{
-    # if vector check acceptable types
+    # if vector check acceptable types 
     pngF = length(which(overwriteSourcePlot == "png")) > 0
     psF = length(which(overwriteSourcePlot == "ps")) > 0
     tiffF = length(which(overwriteSourcePlot == "tiff")) > 0
     jpegF = length(which(overwriteSourcePlot == "jpeg")) > 0
     pdfF = length(which(overwriteSourcePlot == "pdf")) > 0
-
+    
     if(!pngF & !jpegF) pngF = TRUE
-
+     
   }
 
-
+  
   wi = strsplit(Splot$image.size, "x")[[1]][1]
   hi = strsplit(Splot$image.size, "x")[[1]][2]
 
   startFig = "png"
   if(!pngF) startFig = "jpeg"
 
-
+  
   if(startFig == "png"){
     png(filename=fname.png, width=as.double(wi), height=as.double(hi), pointsize=Splot$pointsize, res=Splot$res)
     dev.control("enable")
-
+    
     Splot$plot.output = list()
-
+  
     # initiate layout
     if(max(as.vector(Splot$mat),na.rm=TRUE)>1) nf = layout(Splot$mat, respect=TRUE)
     if(Splot$mai.prc) mai.def=par("mai")
 
-    # initialize getLims
+    # initialize getLims 
     if(is.null(Splot$plot.lims)){
       plot.lims = list()
       plot.lims$xmins = rep(NA, length(Splot$plot.calls))
       plot.lims$xmaxs = rep(NA, length(Splot$plot.calls))
       plot.lims$ymins = rep(NA, length(Splot$plot.calls))
       plot.lims$ymaxs = rep(NA, length(Splot$plot.calls))
-      Splot$plot.lims = plot.lims
+      Splot$plot.lims = plot.lims    
     }
-
+  
     # loop over plot calls to place plots in order or 1:n in layout
     for(i in 1:length(Splot$plot.calls)){
       # set up plot margin
       if(length(Splot$mai.mat)>1){
         if(!Splot$mai.prc) par(mai=Splot$mai.mat[i,])
-        if(Splot$mai.prc)  par(mai=Splot$mai.mat[i,]*mai.def)
+        if(Splot$mai.prc)  par(mai=Splot$mai.mat[i,]*mai.def)            
       }
       # evaluate plot call
       plt = eval.js(Splot$plot.calls[[i]])
@@ -106,7 +106,7 @@ makeSplot <- function(Splot,
         class(Splot$plot.output[i]) = "list"
         Splot$plot.output[[i]] = plt
       }
-
+    
       # cycle through all additional plot calls for current plot
       sub.np = length(Splot$plot.extras[[i]])
       for(sp in 1:sub.np){
@@ -118,7 +118,7 @@ makeSplot <- function(Splot,
       Splot$plot.lims$xmaxs[i] = par()$usr[2]
       Splot$plot.lims$ymins[i] = par()$usr[3]
       Splot$plot.lims$ymaxs[i] = par()$usr[4]
-
+           
     }# end for loop over plot calls
 
 
@@ -138,37 +138,37 @@ makeSplot <- function(Splot,
       dev.copy2pdf(file=fname.pdf,paper=Splot$ps.paper,width=Splot$ps.width,height=Splot$ps.height,pointsize=Splot$pointsize)
       #dev.off()
     }
-    dev.off()
-
+    dev.off() 
+    
 
   }else{
 
     jpeg(filename=fname.jpeg, width=as.double(wi), height=as.double(hi), pointsize=Splot$pointsize, res=Splot$res)
     dev.control("enable")
 
-
+    
     Splot$plot.output = list()
-
+  
     # initiate layout
     if(max(as.vector(Splot$mat),na.rm=TRUE)>1) nf = layout(Splot$mat, respect=TRUE)
     if(Splot$mai.prc) mai.def=par("mai")
 
-    # initialize getLims
+    # initialize getLims 
     if(is.null(Splot$plot.lims)){
       plot.lims = list()
       plot.lims$xmins = rep(NA, length(Splot$plot.calls))
       plot.lims$xmaxs = rep(NA, length(Splot$plot.calls))
       plot.lims$ymins = rep(NA, length(Splot$plot.calls))
       plot.lims$ymaxs = rep(NA, length(Splot$plot.calls))
-      Splot$plot.lims = plot.lims
+      Splot$plot.lims = plot.lims    
     }
-
+  
     # loop over plot calls to place plots in order or 1:n in layout
     for(i in 1:length(Splot$plot.calls)){
       # set up plot margin
       if(length(Splot$mai.mat)>1){
         if(!Splot$mai.prc) par(mai=Splot$mai.mat[i,])
-        if(Splot$mai.prc)  par(mai=Splot$mai.mat[i,]*mai.def)
+        if(Splot$mai.prc)  par(mai=Splot$mai.mat[i,]*mai.def)            
       }
       # evaluate plot call
       plt = eval.js(Splot$plot.calls[[i]])
@@ -179,7 +179,7 @@ makeSplot <- function(Splot,
         class(Splot$plot.output[i]) = "list"
         Splot$plot.output[[i]] = plt
       }
-
+    
       # cycle through all additional plot calls for current plot
       sub.np = length(Splot$plot.extras[[i]])
       for(sp in 1:sub.np){
@@ -191,7 +191,7 @@ makeSplot <- function(Splot,
       Splot$plot.lims$xmaxs[i] = par()$usr[2]
       Splot$plot.lims$ymins[i] = par()$usr[3]
       Splot$plot.lims$ymaxs[i] = par()$usr[4]
-
+           
     }# end for loop over plot calls
 
 
@@ -207,8 +207,8 @@ makeSplot <- function(Splot,
       dev.copy2pdf(file=fname.pdf,paper=Splot$ps.paper,width=Splot$ps.width,height=Splot$ps.height,pointsize=Splot$pointsize)
       #dev.off()
     }
-    dev.off()
-
+    dev.off() 
+        
   } # end else
 
 
@@ -217,26 +217,26 @@ makeSplot <- function(Splot,
 
 
 
-
-
+  
+  
 
 
   #
   # interactive webpage
   #
-
+  
   if(makeInteractive){
-
+    
     # check for interactive plots
     if(!is.na(overrideInteractive[1])){
       if(length(overrideInteractive) != Splot$nfig){
         cat(paste("Note: overrideInteractive is not of correct length\n       Length of overrideInteractve:", length(overrideInteractive),"\n       should be equal to the number of figures:", Splot$nfig, "\n       Continuing with originally set interactive plots \n"))
-        overrideInteractive = NA
+        overrideInteractive = NA            
       }
       if(class(overrideInteractive) != "logical"){
         cat(paste("Note: overrideInteractive is not correct \n       Must be Logical (T/F) vector of length:", Splot$nfig, "\n       Continuing with originally set interactive plots \n"))
-        overrideInteractive = NA
-      }
+        overrideInteractive = NA      
+      }      
     }
     # if override is set use override otherwise use stored Iflag object
     if(is.na(overrideInteractive[1])) Ifig = which(Splot$Iflag)
@@ -246,26 +246,26 @@ makeSplot <- function(Splot,
     if(length(Ifig) !=0){
 
       # checks to make sure at least one of the labelled interactive plots
-      #  does have a mapping
+      #  does have a mapping 
       Fsum = 0
       for(f in Ifig){
         Fsum = Fsum + length(Splot$iMap[[f]])
       }
       if(Fsum != 0){
 
-
+     
            ##############################################################
            ##############################################################
            #
            # eventually need to run a check and combined
            #   duplicate coordinates
            #
-           # print points before regions??
-           #
+           # print points before regions?? 
+           #   
            ##############################################################
            ##############################################################
-
-
+      
+    
         #
         #  combined image mapping and make .html
         #
@@ -274,9 +274,9 @@ makeSplot <- function(Splot,
         # load header information for html file
         if(header!="v1" &  header!="v2" & header!="v3") header="v3"
         # mapfile header info
-        if(header=="v2") data(v2.header)
-        if(header=="v1") data(v1.header)
-
+        if(header=="v2") sp.header= sp.header2 #data(v2.header)
+        if(header=="v1") sp.header= sp.header1 #data(v1.header)
+        
         # begin html file
         sink(fname.html)
         # add header information
@@ -286,22 +286,22 @@ makeSplot <- function(Splot,
 
           cat(paste("<html>\n<head>\n    <title>sendplot</title>\n    <style type=\"text/css\">\n        /* CSS GOES HERE */\n        .plot {border:1px solid #CCCCCC;display:block;overflow:auto;padding:5px;\n               max-width:",w.wi,"px; max-height:",w.hi,"px;}\n    </style>\n</head>\n", sep=""))
 
-          data(v3.header)
-
+          #data(v3.header)
+          sp.header=sp.header3
         }
 
         sp.header=sp.header
-
+        
         for(i in 1:length(sp.header)) cat(sp.header[i],fill=TRUE)
-
-
+   
+        
         # loop over labelled interactive
-        # writing to file
+        # writing to file 
         for(fi in Ifig){
-
+          
           lenList = length(Splot$iMap[[fi]])
           if(lenList != 0){
-
+            
             for(ll in 1:lenList){
 
               obj = Splot$iMap[[fi]][[ll]]
@@ -309,7 +309,7 @@ makeSplot <- function(Splot,
               iType = Splot$iType[[fi]][ll]
               if(header=="v1") writeToHTML1(obj, DFs, iType)
               if(header=="v2" | header=="v3") writeToHTML2(obj, DFs, iType)
-
+              
             }
           }
         }
@@ -320,31 +320,31 @@ makeSplot <- function(Splot,
             if(header=="v2" | header=="v3") writeDefault2(Splot)
           }
         }
-
+        
         cat("</map>",fill=TRUE)
         cat("<div class=\"plot\">",fill=TRUE)
         if(!pngF){
 
           image.name.jpeg=paste(fname.root,".jpeg",sep="")
-
+ 
           if(header=="v1")cat("<img border=\"0\" src=\"",image.name.jpeg,"\" usemap=\"img-map\" />",sep="",fill=TRUE)
-          if(header=="v2" | header=="v3")cat("<img border=\"0\" src=\"",image.name.jpeg,"\" usemap=\"#img-map\" />",sep="",fill=TRUE)
+          if(header=="v2" | header=="v3")cat("<img border=\"0\" src=\"",image.name.jpeg,"\" usemap=\"#img-map\" />",sep="",fill=TRUE)          
         }else{
 
           image.name.png=paste(fname.root,".png",sep="")
-
+           
           if(header=="v1")cat("<img border=\"0\" src=\"",image.name.png,"\" usemap=\"img-map\" />",sep="",fill=TRUE)
           if(header=="v2" | header=="v3")cat("<img border=\"0\" src=\"",image.name.png,"\" usemap=\"#img-map\" />",sep="",fill=TRUE)
         }
         cat("</div>",fill=TRUE)
         cat("</body>",fill=TRUE)
         cat("</html>",fill=TRUE)
-
+        
         sink()
 
         if(header=="v1") cat("Note: hyperlinks currenly only work with header=v2 \n")
 
-
+        
       }else{
         cat("Note:  Plot[s] are labelled as interactive:\n       But none have been mapped\n       Please set using makeImap \n")
       }
@@ -354,9 +354,9 @@ makeSplot <- function(Splot,
       # load header information for html file
       if(header!="v1" &  header!="v2" & header!="v3") header="v3"
       # mapfile header info
-      if(header=="v2") data(v2.header)
-      if(header=="v1") data(v1.header)
-
+      if(header=="v2") sp.header= sp.header2 #data(v2.header)
+      if(header=="v1") sp.header= sp.header1 #data(v1.header)
+        
       # begin html file
       sink(fname.html)
       # add header information
@@ -366,12 +366,12 @@ makeSplot <- function(Splot,
 
         cat(paste("<html>\n<head>\n    <title>sendplot</title>\n    <style type=\"text/css\">\n        /* CSS GOES HERE */\n        .plot {border:1px solid #CCCCCC;display:block;overflow:auto;padding:5px;\n               max-width:",w.wi,"px; max-height:",w.hi,"px;}\n    </style>\n</head>\n", sep=""))
 
-        data(v3.header)
-
+        #data(v3.header)
+        sp.header= sp.header3  
       }
 
       sp.header=sp.header
-
+        
       for(i in 1:length(sp.header)) cat(sp.header[i],fill=TRUE)
 
       if(!is.null(Splot$Default)){
@@ -380,41 +380,41 @@ makeSplot <- function(Splot,
           if(header=="v2" | header=="v3") writeDefault2(Splot)
         }
       }
-
+      
       cat("</map>",fill=TRUE)
       cat("<div class=\"plot\">",fill=TRUE)
       if(!pngF){
-
+        
         image.name.jpeg=paste(fname.root,".jpeg",sep="")
-
+        
         if(header=="v1")cat("<img border=\"0\" src=\"",image.name.jpeg,"\" usemap=\"img-map\" />",sep="",fill=TRUE)
-        if(header=="v2" | header=="v3")cat("<img border=\"0\" src=\"",image.name.jpeg,"\" usemap=\"#img-map\" />",sep="",fill=TRUE)
+        if(header=="v2" | header=="v3")cat("<img border=\"0\" src=\"",image.name.jpeg,"\" usemap=\"#img-map\" />",sep="",fill=TRUE)          
       }else{
-
+        
         image.name.png=paste(fname.root,".png",sep="")
-
+        
         if(header=="v1")cat("<img border=\"0\" src=\"",image.name.png,"\" usemap=\"img-map\" />",sep="",fill=TRUE)
         if(header=="v2" | header=="v3")cat("<img border=\"0\" src=\"",image.name.png,"\" usemap=\"#img-map\" />",sep="",fill=TRUE)
       }
       cat("</div>",fill=TRUE)
       cat("</body>",fill=TRUE)
       cat("</html>",fill=TRUE)
-
+      
       sink()
-
+      
       if(header=="v1") cat("Note: hyperlinks currenly only work with header=v2 \n")
 
 
-
+      
       cat("Note:  No plots are designated interactive \n       Please set using makeImap \n")
     }
-
+    
   }
 
-
+  
   #if(getLims) returnObj = TRUE
   if(returnObj) return(Splot)
-
+  
 }
 
 
